==> crosscompute-0.8.4.6.tar.gz: crosscompute-0.8.4.6/crosscompute/routines/__init__.py <==
from .connection import (
    fetch_resource,
    get_bash_configuration_text,
    get_client_url,
    get_echoes_client,
    get_resource_url,
    get_server_url,
    get_token,
    yield_echo)
from .definition import (
    check_dictionary,
    check_list,
    get_nested_value,
    get_put_dictionary,
    get_template_dictionary,
    load_definition,
    load_raw_definition,
    normalize_automation_definition,
    normalize_block_dictionaries,
    normalize_data,
    normalize_data_dictionary,
    normalize_definition,
    normalize_environment_variable_dictionaries,
    normalize_file_dictionary,
    normalize_project_definition,
    normalize_result_definition,
    normalize_result_variable_dictionaries,
    normalize_style_rule_strings,
    normalize_template_dictionaries,
    normalize_test_dictionaries,
    normalize_tool_definition_body,
    normalize_tool_definition_head,
    normalize_tool_variable_dictionaries,
    normalize_value)
from .execution import (
    get_result_name,
    load_relevant_path,
    prepare_dataset,
    process_result_definition,
    process_variable_folder,
    run_automation,
    run_script,
    run_tests,
    run_tool,
    run_worker)
from .serialization import (
    load_image_png,
    load_map_geojson,
    load_markdown_md,
    load_number_json,
    load_table_csv,
    load_text_json,
    load_text_txt,
    load_value_json,
    render_object,
    save_image_png,
    save_map_geojson,
    save_markdown_md,
    save_number_json,
    save_table_csv,
    save_text_json,
    save_text_txt)


# flake8: noqa: E401

==> crosscompute-0.8.4.7.tar.gz: crosscompute-0.8.4.7/crosscompute/routines/__init__.py <==
from .connection import (
    fetch_resource,
    get_bash_configuration_text,
    get_client_url,
    get_echoes_client,
    get_resource_url,
    get_server_url,
    get_token,
    yield_echo)
from .definition import (
    check_dictionary,
    check_list,
    get_nested_value,
    get_put_dictionary,
    get_template_dictionary,
    load_definition,
    load_raw_definition,
    normalize_automation_definition,
    normalize_block_dictionaries,
    normalize_data,
    normalize_data_dictionary,
    normalize_definition,
    normalize_environment_variable_dictionaries,
    normalize_file_dictionary,
    normalize_project_definition,
    normalize_result_definition,
    normalize_result_variable_dictionaries,
    normalize_style_rule_strings,
    normalize_test_dictionaries,
    normalize_tool_definition_body,
    normalize_tool_definition_head,
    normalize_tool_template_dictionaries,
    normalize_tool_variable_dictionaries,
    normalize_value)
from .execution import (
    get_result_name,
    load_relevant_path,
    prepare_dataset,
    process_result_definition,
    process_variable_folder,
    run_automation,
    run_script,
    run_tests,
    run_tool,
    run_worker)
from .serialization import (
    load_image_png,
    load_map_geojson,
    load_markdown_md,
    load_number_json,
    load_table_csv,
    load_text_json,
    load_text_txt,
    load_value_json,
    render_object,
    save_image_png,
    save_map_geojson,
    save_markdown_md,
    save_number_json,
    save_table_csv,
    save_text_json,
    save_text_txt)


# flake8: noqa: E401
